export interface Cookie {
    name: string;
    value?: string;
    maxAge?: number;
    expires?: Date;
    path?: string;
    domain?: string;
    secure?: boolean;
    httpOnly?: boolean;
    sameSite?: boolean | 'strict' | 'lax';
    overwrite?: boolean;
}
export declare class Result {
    readonly status: number;
    readonly value?: unknown;
    readonly cookies?: Cookie[] | undefined;
    readonly headers?: Record<string, string> | undefined;
    protected constructor(status: number, value?: unknown, cookies?: Cookie[] | undefined, headers?: Record<string, string> | undefined);
}
export declare class DataResult extends Result {
    private readonly __type;
    private constructor();
    static ok(value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): DataResult;
    static error(value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): DataResult;
    static notFound(cookies?: Cookie[], headers?: Record<string, string>): DataResult;
    static unauthorized(cookies?: Cookie[], headers?: Record<string, string>): DataResult;
}
export declare class ViewResult extends Result {
    private readonly __type;
    template?: string;
    redirectUrl?: string;
    private constructor();
    static ok(template: string, value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): ViewResult;
    static redirect(url: string, status?: 301 | 302, cookies?: Cookie[], headers?: Record<string, string>): ViewResult;
    static error(template: string, value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): ViewResult;
    static notFound(template: string, value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): ViewResult;
    static unauthorized(template: string, value?: unknown, cookies?: Cookie[], headers?: Record<string, string>): ViewResult;
}
