"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Result {
    constructor(status, value, cookies, headers) {
        this.status = status;
        this.value = value;
        this.cookies = cookies;
        this.headers = headers;
    }
}
exports.Result = Result;
class DataResult extends Result {
    constructor(status, value, cookies, headers) {
        super(status, value, cookies, headers);
        // dummy read to compile - see notes above
        this.__type;
    }
    static ok(value, cookies, headers) {
        const status = value ? 200 : 204;
        return new DataResult(status, value, cookies, headers);
    }
    static error(value, cookies, headers) {
        return new DataResult(400, value, cookies, headers);
    }
    static notFound(cookies, headers) {
        return new DataResult(404, undefined, cookies, headers);
    }
    static unauthorized(cookies, headers) {
        return new DataResult(401, undefined, cookies, headers);
    }
}
exports.DataResult = DataResult;
class ViewResult extends Result {
    constructor(status, value, cookies, headers, template, redirectUrl) {
        super(status, value, cookies, headers);
        // Dummy read to compile
        this.__type;
        this.template = template;
        this.redirectUrl = redirectUrl;
    }
    static ok(template, value, cookies, headers) {
        return new ViewResult(200, value, cookies, headers, template);
    }
    static redirect(url, status = 302, cookies, headers) {
        return new ViewResult(status, undefined, cookies, headers, undefined, url);
    }
    static error(template, value, cookies, headers) {
        return new ViewResult(400, value, cookies, headers, template);
    }
    static notFound(template, value, cookies, headers) {
        return new ViewResult(404, value, cookies, headers, template);
    }
    static unauthorized(template, value, cookies, headers) {
        return new ViewResult(401, value, cookies, headers, template);
    }
}
exports.ViewResult = ViewResult;
//# sourceMappingURL=result.js.map